pub struct InstallConfig { /* private fields */ }Expand description
Represents a list of tasks for a SETUP.install operation.
Implementations
Sourceimpl InstallConfig
impl InstallConfig
Sourcepub fn push<T: SetupTask>(
&mut self,
name: impl Into<Txt>,
config: T::InstallConfig,
)
pub fn push<T: SetupTask>( &mut self, name: impl Into<Txt>, config: T::InstallConfig, )
Push a task to run.
The name is used to identify the task instance in progress status.
Sourcepub fn tasks(&self) -> &[(TaskTypeId, Txt)]
pub fn tasks(&self) -> &[(TaskTypeId, Txt)]
Task types and names in order they will execute.