pub struct PreparedInstallConfig { /* private fields */ }Expand description
Represents data generated by SETUP.prepare_install that can be used to run a SETUP.commit_install operation.
Implementations
Sourceimpl PreparedInstallConfig
impl PreparedInstallConfig
Sourcepub fn tasks(&self) -> &[(TaskTypeId, Txt)]
pub fn tasks(&self) -> &[(TaskTypeId, Txt)]
Task types and names in order they will execute.
Sourceimpl PreparedInstallConfig
impl PreparedInstallConfig
Sourcepub fn save_blocking(&self, file: &Path) -> Result<()>
pub fn save_blocking(&self, file: &Path) -> Result<()>
Serialize and write config to file.
The format is a ZStandard compressed JSON.
Sourcepub async fn save(self, file: PathBuf) -> Result<()>
pub async fn save(self, file: PathBuf) -> Result<()>
Serialize and write config to file.
The format is a ZStandard compressed JSON.
Sourcepub fn load_blocking(file: &Path) -> Result<Self>
pub fn load_blocking(file: &Path) -> Result<Self>
Read and deserialize config from file.
The format must be a ZStandard compressed JSON.