SfxClient

Struct SfxClient 

pub struct SfxClient { /* private fields */ }
Connection with a self-extracting executable generated by cargo zng res --tool sfx.

Implementations

Source

impl SfxClient

pub fn connect_blocking() -> Result<Self, SfxError>

Connect with the “SFX_ARGS” defined server.

pub async fn connect() -> Result<Self, SfxError>

Connect with the “SFX_ARGS” defined server.

pub fn sfx_exe(&self) -> &Path

The SFX server executable.

This is the sfx_args()[0] value.

pub fn sfx_args(&self) -> &[Txt]

The command line arguments from the SFX executable.

Note that the sfx process that spawned this process is still running and replicating stdout/err from this process, impersonating the extracted executable.

These args are from the user, the std::env::args are from the sfx tool and are usually empty.

pub fn manifest(&self) -> &[SfxDataInfo]

Info an all data the server can provide.

List is sorted by name.

pub fn info(&self, name: &str) -> Option<&SfxDataInfo>

Get name data info it it is in the server manifest.

pub fn read_blocking(&self, name: &str) -> Result<SfxReadBlocking, SfxError>

Read raw data.

The sfx server will automatically decompress/decode data that was marked compress on build.

pub async fn read(&self, name: &str) -> Result<SfxRead, SfxError>

Read raw data.

The sfx server will automatically decompress/decode data that was marked compress on build.