pub struct CreateShortcutConfig {
pub link_file: PathBuf,
pub target_file: PathBuf,
pub working_dir: PathBuf,
pub args: Vec<String>,
pub app_id: String,
pub name: String,
pub icon: PathBuf,
}Expand description
Config for CreateShortcut.
Fields
link_file: PathBufPath to the shortcut, without extension.
target_file: PathBufPath to the shortcut target executable file.
working_dir: PathBufPath to the initial current_dir of the executable.
Default
Empty is the target_file parent executable.
args: Vec<String>Arguments to pass the executable.
app_id: StringGlobally unique app ID.
This is only used on Windows to set the AUMID on the shortcut, this must be
the same value as zng::env::About::windows_aumid on the app executable. Note that
if the app does not have a shortcut on the Start Menu that defines the ID notifications
and other shell integrations will not work properly.
Default
If this is empty the zng::env::About::windows_aumid value is used. Note that this is only valid
if the setup app is defined on the same app executable.
name: Stringicon: PathBufOptional icon for the shortcut.
Default
Empty is the target_file icon 0 in Windows, and no icon in Linux.
Implementations