pub struct ExtractTarConfig { /* private fields */ }Expand description
Config for ExtractTar
Implementations
Sourceimpl ExtractTarConfig
impl ExtractTarConfig
Sourcepub fn new(tar_len: u64, tar: Box<dyn Read + Send>, target_dir: PathBuf) -> Self
pub fn new(tar_len: u64, tar: Box<dyn Read + Send>, target_dir: PathBuf) -> Self
New config.
tar_lenestimated length oftar, used for progress reporting only. Pass0for indeterminate.tarmust read only a TAR stream from start to end. Must contain only directory and file entries.target_dirDirectory that will be created or merged with thetarroot directory.
If all entries share a common first path component (for example, my-app/bin/app.exe and my-app/README.md),
that directory is created inside target_dir. To extract files directly into target_dir, the entries must
not have a common leading directory component.
Sourcepub fn from_sfx(tar: SfxReadBlocking, target_dir: PathBuf) -> Self
pub fn from_sfx(tar: SfxReadBlocking, target_dir: PathBuf) -> Self
New config from a SfxClient read stream.