InstallTaskError

Struct InstallTaskError 

pub struct InstallTaskError<I> {
    pub error: SetupTaskError,
    pub clean_data: Option<I>,
}
Error in a SetupTask::install task run.

Fields

error: SetupTaskError

The error.

clean_data: Option<I>

Cleanup SetupTask::Install data.

This must contain data to uninstall the partial committed changes, if there where any. Task runners may use this to attempt a SetupTask::uninstall to cleanup the corrupted install.

In case the install is an update, this must also contain all data from the previous install that has not been invalidated by the failed install.

If this is None the task runner will show that the task corrupted the install and the changes made cannot even be uninstalled. It will also assume that the SetupTask::PrepareInstall data was not fully cleaned before the error.

If this is Some the task runner will assume the SetupTask::PrepareInstall is fully cleaned. The task must attempt to run a cancel on the partial prepared data that has not committed yet, if the error was encountered before any changes where actually committed and all prepared changes where successfully canceled this must be set to Some value that represents an empty install that the uninstall task will recognize and immediately return success for.