PrepareInstallArgs

Struct PrepareInstallArgs 

#[non_exhaustive]
pub struct PrepareInstallArgs<T: SetupTask> { pub config: T::InstallConfig, pub update: Option<T::Install>, pub progress: Var<Progress>, pub cancel: Var<bool>, }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
config: T::InstallConfig

Config for the new installation.

update: Option<T::Install>

Data from the previous installation that is being replaced with this one.

This is set if is installing over a previous installation and the same task is present on the new installation.

progress: Var<Progress>

Progress indicator for the task. Starts as Progress::indeterminate by default.

cancel: Var<bool>

Read-only var that is true if the user cancels the installation.

If possible check this flag often and return immediately on cancel. The prepare install step is not expected to cleanup on cancel, just return immediately.